# kurek
**kurek** lets users download data from [zbiornik.com](https://zbiornik.com).

The script uses your private account login information to retrieve photos and 
videos from profiles that you pass to it. It uses the site's API and finds 
download links for media available in highest fidelity available to you.
Files are collected using *asyncio*-adjacent libraries - it's quite fast. 

This project is under heavy development, but the basic functionality is already
there.

# Features
- Written in Python3
- Uses *aiohttp* and *aiofiles* libraries for fast downloads
- It provides many flags to modify its behavior. Use *-h* to see them all
- Works perfectly on Linux

# TODO
- *curses* interface for tracking download progress
- Downloading media from Top Lists for a date in time - even those not freely
  available on the website interface
- Automatic testing
- Prepare a Docker image for ease of use

# Support

If you like the project, buy me a coffee:

[![ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/I3I1DUJRM) [![paypal](https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif)](https://www.paypal.me/bartibart/5)

Paypal: @bartibart

BTC: bc1q27cychp3vcrw2p6z93w3jxlug5d8pn4fkvsrrv

ETH: 0xbdA7FF30080a83Ef7aED5532B8f2dAdf839d6111

DOGE: DNjPH5M3CPRs82raU2qzLWzRDroJpAKVah

XMR: 43jMmHCMKPaNLwHxGkNW9m8ScFck5vrgC3YEy6gSKzyDYMU3ous7S9jEFKRTAdYnBqdGCj2G2jV545JMRxFnUML1UyRspZN


